@@ -117,7 +117,7 @@ class LetsEncrypt:
             self.hostname).subdomain
         subprocess.call(
             '{directory}/acme.sh/acme.sh --upgrade'.format(directory=os.getenv('HOME')), shell=True)
-        subprocess.call('{directory}/acme.sh/acme.sh --set-default-ca --server letsencrypt --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --preferred-chain "ISRG Root X1" --force'.format(
+        subprocess.call('{directory}/acme.sh/acme.sh --set-default-ca --server letsencrypt --preferred-chain "ISRG" --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --force'.format(
             directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{subdomain}.{self.subdelegate}'), shell=True)
 
     def acme_local(self, csr: str) -> None:  # pragma: no cover
